import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AppSyncClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AppSyncClient";
import { ListChannelNamespacesRequest, ListChannelNamespacesResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListChannelNamespacesCommand}.
 */
export interface ListChannelNamespacesCommandInput extends ListChannelNamespacesRequest {
}
/**
 * @public
 *
 * The output of {@link ListChannelNamespacesCommand}.
 */
export interface ListChannelNamespacesCommandOutput extends ListChannelNamespacesResponse, __MetadataBearer {
}
declare const ListChannelNamespacesCommand_base: {
    new (input: ListChannelNamespacesCommandInput): import("@smithy/smithy-client").CommandImpl<ListChannelNamespacesCommandInput, ListChannelNamespacesCommandOutput, AppSyncClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: ListChannelNamespacesCommandInput): import("@smithy/smithy-client").CommandImpl<ListChannelNamespacesCommandInput, ListChannelNamespacesCommandOutput, AppSyncClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists the channel namespaces for a specified <code>Api</code>.</p>
 *          <p>
 *             <code>ListChannelNamespaces</code> returns only high level details for the channel
 *          namespace. To retrieve code handlers, use <code>GetChannelNamespace</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AppSyncClient, ListChannelNamespacesCommand } from "@aws-sdk/client-appsync"; // ES Modules import
 * // const { AppSyncClient, ListChannelNamespacesCommand } = require("@aws-sdk/client-appsync"); // CommonJS import
 * const client = new AppSyncClient(config);
 * const input = { // ListChannelNamespacesRequest
 *   apiId: "STRING_VALUE", // required
 *   nextToken: "STRING_VALUE",
 *   maxResults: Number("int"),
 * };
 * const command = new ListChannelNamespacesCommand(input);
 * const response = await client.send(command);
 * // { // ListChannelNamespacesResponse
 * //   channelNamespaces: [ // ChannelNamespaces
 * //     { // ChannelNamespace
 * //       apiId: "STRING_VALUE",
 * //       name: "STRING_VALUE",
 * //       subscribeAuthModes: [ // AuthModes
 * //         { // AuthMode
 * //           authType: "API_KEY" || "AWS_IAM" || "AMAZON_COGNITO_USER_POOLS" || "OPENID_CONNECT" || "AWS_LAMBDA", // required
 * //         },
 * //       ],
 * //       publishAuthModes: [
 * //         {
 * //           authType: "API_KEY" || "AWS_IAM" || "AMAZON_COGNITO_USER_POOLS" || "OPENID_CONNECT" || "AWS_LAMBDA", // required
 * //         },
 * //       ],
 * //       codeHandlers: "STRING_VALUE",
 * //       tags: { // TagMap
 * //         "<keys>": "STRING_VALUE",
 * //       },
 * //       channelNamespaceArn: "STRING_VALUE",
 * //       created: new Date("TIMESTAMP"),
 * //       lastModified: new Date("TIMESTAMP"),
 * //       handlerConfigs: { // HandlerConfigs
 * //         onPublish: { // HandlerConfig
 * //           behavior: "CODE" || "DIRECT", // required
 * //           integration: { // Integration
 * //             dataSourceName: "STRING_VALUE", // required
 * //             lambdaConfig: { // LambdaConfig
 * //               invokeType: "REQUEST_RESPONSE" || "EVENT",
 * //             },
 * //           },
 * //         },
 * //         onSubscribe: {
 * //           behavior: "CODE" || "DIRECT", // required
 * //           integration: {
 * //             dataSourceName: "STRING_VALUE", // required
 * //             lambdaConfig: {
 * //               invokeType: "REQUEST_RESPONSE" || "EVENT",
 * //             },
 * //           },
 * //         },
 * //       },
 * //     },
 * //   ],
 * //   nextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListChannelNamespacesCommandInput - {@link ListChannelNamespacesCommandInput}
 * @returns {@link ListChannelNamespacesCommandOutput}
 * @see {@link ListChannelNamespacesCommandInput} for command's `input` shape.
 * @see {@link ListChannelNamespacesCommandOutput} for command's `response` shape.
 * @see {@link AppSyncClientResolvedConfig | config} for AppSyncClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p>The request is not well formed. For example, a value is invalid or a required field is
 *          missing. Check the field values, and then try again.</p>
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An internal AppSync error occurred. Try your request again.</p>
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p>The resource specified in the request was not found. Check the resource, and then try
 *          again.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>You aren't authorized to perform this operation.</p>
 *
 * @throws {@link AppSyncServiceException}
 * <p>Base exception class for all service exceptions from AppSync service.</p>
 *
 *
 * @public
 */
export declare class ListChannelNamespacesCommand extends ListChannelNamespacesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListChannelNamespacesRequest;
            output: ListChannelNamespacesResponse;
        };
        sdk: {
            input: ListChannelNamespacesCommandInput;
            output: ListChannelNamespacesCommandOutput;
        };
    };
}
