import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AppSyncClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AppSyncClient";
import { StartSchemaMergeRequest, StartSchemaMergeResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link StartSchemaMergeCommand}.
 */
export interface StartSchemaMergeCommandInput extends StartSchemaMergeRequest {
}
/**
 * @public
 *
 * The output of {@link StartSchemaMergeCommand}.
 */
export interface StartSchemaMergeCommandOutput extends StartSchemaMergeResponse, __MetadataBearer {
}
declare const StartSchemaMergeCommand_base: {
    new (input: StartSchemaMergeCommandInput): import("@smithy/smithy-client").CommandImpl<StartSchemaMergeCommandInput, StartSchemaMergeCommandOutput, AppSyncClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (input: StartSchemaMergeCommandInput): import("@smithy/smithy-client").CommandImpl<StartSchemaMergeCommandInput, StartSchemaMergeCommandOutput, AppSyncClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Initiates a merge operation. Returns a status that shows the result of the merge
 *          operation.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AppSyncClient, StartSchemaMergeCommand } from "@aws-sdk/client-appsync"; // ES Modules import
 * // const { AppSyncClient, StartSchemaMergeCommand } = require("@aws-sdk/client-appsync"); // CommonJS import
 * const client = new AppSyncClient(config);
 * const input = { // StartSchemaMergeRequest
 *   associationId: "STRING_VALUE", // required
 *   mergedApiIdentifier: "STRING_VALUE", // required
 * };
 * const command = new StartSchemaMergeCommand(input);
 * const response = await client.send(command);
 * // { // StartSchemaMergeResponse
 * //   sourceApiAssociationStatus: "MERGE_SCHEDULED" || "MERGE_FAILED" || "MERGE_SUCCESS" || "MERGE_IN_PROGRESS" || "AUTO_MERGE_SCHEDULE_FAILED" || "DELETION_SCHEDULED" || "DELETION_IN_PROGRESS" || "DELETION_FAILED",
 * // };
 *
 * ```
 *
 * @param StartSchemaMergeCommandInput - {@link StartSchemaMergeCommandInput}
 * @returns {@link StartSchemaMergeCommandOutput}
 * @see {@link StartSchemaMergeCommandInput} for command's `input` shape.
 * @see {@link StartSchemaMergeCommandOutput} for command's `response` shape.
 * @see {@link AppSyncClientResolvedConfig | config} for AppSyncClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p>The request is not well formed. For example, a value is invalid or a required field is
 *          missing. Check the field values, and then try again.</p>
 *
 * @throws {@link ConcurrentModificationException} (client fault)
 *  <p>Another modification is in progress at this time and it must complete before you can
 *          make your change.</p>
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An internal AppSync error occurred. Try your request again.</p>
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p>The resource specified in the request was not found. Check the resource, and then try
 *          again.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>You aren't authorized to perform this operation.</p>
 *
 * @throws {@link AppSyncServiceException}
 * <p>Base exception class for all service exceptions from AppSync service.</p>
 *
 *
 * @public
 */
export declare class StartSchemaMergeCommand extends StartSchemaMergeCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: StartSchemaMergeRequest;
            output: StartSchemaMergeResponse;
        };
        sdk: {
            input: StartSchemaMergeCommandInput;
            output: StartSchemaMergeCommandOutput;
        };
    };
}
