import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { AppSyncServiceException as __BaseException } from "./AppSyncServiceException";
export declare class AccessDeniedException extends __BaseException {
  readonly name: "AccessDeniedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<AccessDeniedException, __BaseException>
  );
}
export declare const AuthenticationType: {
  readonly AMAZON_COGNITO_USER_POOLS: "AMAZON_COGNITO_USER_POOLS";
  readonly API_KEY: "API_KEY";
  readonly AWS_IAM: "AWS_IAM";
  readonly AWS_LAMBDA: "AWS_LAMBDA";
  readonly OPENID_CONNECT: "OPENID_CONNECT";
};
export type AuthenticationType =
  (typeof AuthenticationType)[keyof typeof AuthenticationType];
export interface LambdaAuthorizerConfig {
  authorizerResultTtlInSeconds?: number | undefined;
  authorizerUri: string | undefined;
  identityValidationExpression?: string | undefined;
}
export interface OpenIDConnectConfig {
  issuer: string | undefined;
  clientId?: string | undefined;
  iatTTL?: number | undefined;
  authTTL?: number | undefined;
}
export interface CognitoUserPoolConfig {
  userPoolId: string | undefined;
  awsRegion: string | undefined;
  appIdClientRegex?: string | undefined;
}
export interface AdditionalAuthenticationProvider {
  authenticationType?: AuthenticationType | undefined;
  openIDConnectConfig?: OpenIDConnectConfig | undefined;
  userPoolConfig?: CognitoUserPoolConfig | undefined;
  lambdaAuthorizerConfig?: LambdaAuthorizerConfig | undefined;
}
export interface CognitoConfig {
  userPoolId: string | undefined;
  awsRegion: string | undefined;
  appIdClientRegex?: string | undefined;
}
export interface AuthProvider {
  authType: AuthenticationType | undefined;
  cognitoConfig?: CognitoConfig | undefined;
  openIDConnectConfig?: OpenIDConnectConfig | undefined;
  lambdaAuthorizerConfig?: LambdaAuthorizerConfig | undefined;
}
export interface AuthMode {
  authType: AuthenticationType | undefined;
}
export declare const EventLogLevel: {
  readonly ALL: "ALL";
  readonly DEBUG: "DEBUG";
  readonly ERROR: "ERROR";
  readonly INFO: "INFO";
  readonly NONE: "NONE";
};
export type EventLogLevel = (typeof EventLogLevel)[keyof typeof EventLogLevel];
export interface EventLogConfig {
  logLevel: EventLogLevel | undefined;
  cloudWatchLogsRoleArn: string | undefined;
}
export interface EventConfig {
  authProviders: AuthProvider[] | undefined;
  connectionAuthModes: AuthMode[] | undefined;
  defaultPublishAuthModes: AuthMode[] | undefined;
  defaultSubscribeAuthModes: AuthMode[] | undefined;
  logConfig?: EventLogConfig | undefined;
}
export interface Api {
  apiId?: string | undefined;
  name?: string | undefined;
  ownerContact?: string | undefined;
  tags?: Record<string, string> | undefined;
  dns?: Record<string, string> | undefined;
  apiArn?: string | undefined;
  created?: Date | undefined;
  xrayEnabled?: boolean | undefined;
  wafWebAclArn?: string | undefined;
  eventConfig?: EventConfig | undefined;
}
export declare const AssociationStatus: {
  readonly Failed: "FAILED";
  readonly Processing: "PROCESSING";
  readonly Success: "SUCCESS";
};
export type AssociationStatus =
  (typeof AssociationStatus)[keyof typeof AssociationStatus];
export interface ApiAssociation {
  domainName?: string | undefined;
  apiId?: string | undefined;
  associationStatus?: AssociationStatus | undefined;
  deploymentDetail?: string | undefined;
}
export declare const ApiCachingBehavior: {
  readonly FULL_REQUEST_CACHING: "FULL_REQUEST_CACHING";
  readonly OPERATION_LEVEL_CACHING: "OPERATION_LEVEL_CACHING";
  readonly PER_RESOLVER_CACHING: "PER_RESOLVER_CACHING";
};
export type ApiCachingBehavior =
  (typeof ApiCachingBehavior)[keyof typeof ApiCachingBehavior];
export declare const CacheHealthMetricsConfig: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type CacheHealthMetricsConfig =
  (typeof CacheHealthMetricsConfig)[keyof typeof CacheHealthMetricsConfig];
export declare const ApiCacheStatus: {
  readonly AVAILABLE: "AVAILABLE";
  readonly CREATING: "CREATING";
  readonly DELETING: "DELETING";
  readonly FAILED: "FAILED";
  readonly MODIFYING: "MODIFYING";
};
export type ApiCacheStatus =
  (typeof ApiCacheStatus)[keyof typeof ApiCacheStatus];
export declare const ApiCacheType: {
  readonly LARGE: "LARGE";
  readonly LARGE_12X: "LARGE_12X";
  readonly LARGE_2X: "LARGE_2X";
  readonly LARGE_4X: "LARGE_4X";
  readonly LARGE_8X: "LARGE_8X";
  readonly MEDIUM: "MEDIUM";
  readonly R4_2XLARGE: "R4_2XLARGE";
  readonly R4_4XLARGE: "R4_4XLARGE";
  readonly R4_8XLARGE: "R4_8XLARGE";
  readonly R4_LARGE: "R4_LARGE";
  readonly R4_XLARGE: "R4_XLARGE";
  readonly SMALL: "SMALL";
  readonly T2_MEDIUM: "T2_MEDIUM";
  readonly T2_SMALL: "T2_SMALL";
  readonly XLARGE: "XLARGE";
};
export type ApiCacheType = (typeof ApiCacheType)[keyof typeof ApiCacheType];
export interface ApiCache {
  ttl?: number | undefined;
  apiCachingBehavior?: ApiCachingBehavior | undefined;
  transitEncryptionEnabled?: boolean | undefined;
  atRestEncryptionEnabled?: boolean | undefined;
  type?: ApiCacheType | undefined;
  status?: ApiCacheStatus | undefined;
  healthMetricsConfig?: CacheHealthMetricsConfig | undefined;
}
export interface ApiKey {
  id?: string | undefined;
  description?: string | undefined;
  expires?: number | undefined;
  deletes?: number | undefined;
}
export declare class ApiKeyLimitExceededException extends __BaseException {
  readonly name: "ApiKeyLimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ApiKeyLimitExceededException, __BaseException>
  );
}
export declare class ApiKeyValidityOutOfBoundsException extends __BaseException {
  readonly name: "ApiKeyValidityOutOfBoundsException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ApiKeyValidityOutOfBoundsException,
      __BaseException
    >
  );
}
export declare class ApiLimitExceededException extends __BaseException {
  readonly name: "ApiLimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ApiLimitExceededException, __BaseException>
  );
}
export declare const RuntimeName: {
  readonly APPSYNC_JS: "APPSYNC_JS";
};
export type RuntimeName = (typeof RuntimeName)[keyof typeof RuntimeName];
export interface AppSyncRuntime {
  name: RuntimeName | undefined;
  runtimeVersion: string | undefined;
}
export interface AssociateApiRequest {
  domainName: string | undefined;
  apiId: string | undefined;
}
export interface AssociateApiResponse {
  apiAssociation?: ApiAssociation | undefined;
}
export interface CodeErrorLocation {
  line?: number | undefined;
  column?: number | undefined;
  span?: number | undefined;
}
export interface CodeError {
  errorType?: string | undefined;
  value?: string | undefined;
  location?: CodeErrorLocation | undefined;
}
export interface BadRequestDetail {
  codeErrors?: CodeError[] | undefined;
}
export declare const BadRequestReason: {
  readonly CODE_ERROR: "CODE_ERROR";
};
export type BadRequestReason =
  (typeof BadRequestReason)[keyof typeof BadRequestReason];
export declare class BadRequestException extends __BaseException {
  readonly name: "BadRequestException";
  readonly $fault: "client";
  reason?: BadRequestReason | undefined;
  detail?: BadRequestDetail | undefined;
  constructor(
    opts: __ExceptionOptionType<BadRequestException, __BaseException>
  );
}
export declare class InternalFailureException extends __BaseException {
  readonly name: "InternalFailureException";
  readonly $fault: "server";
  constructor(
    opts: __ExceptionOptionType<InternalFailureException, __BaseException>
  );
}
export declare class NotFoundException extends __BaseException {
  readonly name: "NotFoundException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<NotFoundException, __BaseException>);
}
export declare const MergeType: {
  readonly AUTO_MERGE: "AUTO_MERGE";
  readonly MANUAL_MERGE: "MANUAL_MERGE";
};
export type MergeType = (typeof MergeType)[keyof typeof MergeType];
export interface SourceApiAssociationConfig {
  mergeType?: MergeType | undefined;
}
export interface AssociateMergedGraphqlApiRequest {
  sourceApiIdentifier: string | undefined;
  mergedApiIdentifier: string | undefined;
  description?: string | undefined;
  sourceApiAssociationConfig?: SourceApiAssociationConfig | undefined;
}
export declare const SourceApiAssociationStatus: {
  readonly AUTO_MERGE_SCHEDULE_FAILED: "AUTO_MERGE_SCHEDULE_FAILED";
  readonly DELETION_FAILED: "DELETION_FAILED";
  readonly DELETION_IN_PROGRESS: "DELETION_IN_PROGRESS";
  readonly DELETION_SCHEDULED: "DELETION_SCHEDULED";
  readonly MERGE_FAILED: "MERGE_FAILED";
  readonly MERGE_IN_PROGRESS: "MERGE_IN_PROGRESS";
  readonly MERGE_SCHEDULED: "MERGE_SCHEDULED";
  readonly MERGE_SUCCESS: "MERGE_SUCCESS";
};
export type SourceApiAssociationStatus =
  (typeof SourceApiAssociationStatus)[keyof typeof SourceApiAssociationStatus];
export interface SourceApiAssociation {
  associationId?: string | undefined;
  associationArn?: string | undefined;
  sourceApiId?: string | undefined;
  sourceApiArn?: string | undefined;
  mergedApiArn?: string | undefined;
  mergedApiId?: string | undefined;
  description?: string | undefined;
  sourceApiAssociationConfig?: SourceApiAssociationConfig | undefined;
  sourceApiAssociationStatus?: SourceApiAssociationStatus | undefined;
  sourceApiAssociationStatusDetail?: string | undefined;
  lastSuccessfulMergeDate?: Date | undefined;
}
export interface AssociateMergedGraphqlApiResponse {
  sourceApiAssociation?: SourceApiAssociation | undefined;
}
export declare class ConcurrentModificationException extends __BaseException {
  readonly name: "ConcurrentModificationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ConcurrentModificationException,
      __BaseException
    >
  );
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export declare class UnauthorizedException extends __BaseException {
  readonly name: "UnauthorizedException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<UnauthorizedException, __BaseException>
  );
}
export interface AssociateSourceGraphqlApiRequest {
  mergedApiIdentifier: string | undefined;
  sourceApiIdentifier: string | undefined;
  description?: string | undefined;
  sourceApiAssociationConfig?: SourceApiAssociationConfig | undefined;
}
export interface AssociateSourceGraphqlApiResponse {
  sourceApiAssociation?: SourceApiAssociation | undefined;
}
export declare const AuthorizationType: {
  readonly AWS_IAM: "AWS_IAM";
};
export type AuthorizationType =
  (typeof AuthorizationType)[keyof typeof AuthorizationType];
export interface AwsIamConfig {
  signingRegion?: string | undefined;
  signingServiceName?: string | undefined;
}
export interface AuthorizationConfig {
  authorizationType: AuthorizationType | undefined;
  awsIamConfig?: AwsIamConfig | undefined;
}
export interface CreateApiRequest {
  name: string | undefined;
  ownerContact?: string | undefined;
  tags?: Record<string, string> | undefined;
  eventConfig?: EventConfig | undefined;
}
export interface CreateApiResponse {
  api?: Api | undefined;
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export interface CreateApiCacheRequest {
  apiId: string | undefined;
  ttl: number | undefined;
  transitEncryptionEnabled?: boolean | undefined;
  atRestEncryptionEnabled?: boolean | undefined;
  apiCachingBehavior: ApiCachingBehavior | undefined;
  type: ApiCacheType | undefined;
  healthMetricsConfig?: CacheHealthMetricsConfig | undefined;
}
export interface CreateApiCacheResponse {
  apiCache?: ApiCache | undefined;
}
export interface CreateApiKeyRequest {
  apiId: string | undefined;
  description?: string | undefined;
  expires?: number | undefined;
}
export interface CreateApiKeyResponse {
  apiKey?: ApiKey | undefined;
}
export declare class ConflictException extends __BaseException {
  readonly name: "ConflictException";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
export declare const HandlerBehavior: {
  readonly CODE: "CODE";
  readonly DIRECT: "DIRECT";
};
export type HandlerBehavior =
  (typeof HandlerBehavior)[keyof typeof HandlerBehavior];
export declare const InvokeType: {
  readonly EVENT: "EVENT";
  readonly REQUEST_RESPONSE: "REQUEST_RESPONSE";
};
export type InvokeType = (typeof InvokeType)[keyof typeof InvokeType];
export interface LambdaConfig {
  invokeType?: InvokeType | undefined;
}
export interface Integration {
  dataSourceName: string | undefined;
  lambdaConfig?: LambdaConfig | undefined;
}
export interface HandlerConfig {
  behavior: HandlerBehavior | undefined;
  integration: Integration | undefined;
}
export interface HandlerConfigs {
  onPublish?: HandlerConfig | undefined;
  onSubscribe?: HandlerConfig | undefined;
}
export interface CreateChannelNamespaceRequest {
  apiId: string | undefined;
  name: string | undefined;
  subscribeAuthModes?: AuthMode[] | undefined;
  publishAuthModes?: AuthMode[] | undefined;
  codeHandlers?: string | undefined;
  tags?: Record<string, string> | undefined;
  handlerConfigs?: HandlerConfigs | undefined;
}
export interface ChannelNamespace {
  apiId?: string | undefined;
  name?: string | undefined;
  subscribeAuthModes?: AuthMode[] | undefined;
  publishAuthModes?: AuthMode[] | undefined;
  codeHandlers?: string | undefined;
  tags?: Record<string, string> | undefined;
  channelNamespaceArn?: string | undefined;
  created?: Date | undefined;
  lastModified?: Date | undefined;
  handlerConfigs?: HandlerConfigs | undefined;
}
export interface CreateChannelNamespaceResponse {
  channelNamespace?: ChannelNamespace | undefined;
}
export interface DeltaSyncConfig {
  baseTableTTL?: number | undefined;
  deltaSyncTableName?: string | undefined;
  deltaSyncTableTTL?: number | undefined;
}
export interface DynamodbDataSourceConfig {
  tableName: string | undefined;
  awsRegion: string | undefined;
  useCallerCredentials?: boolean | undefined;
  deltaSyncConfig?: DeltaSyncConfig | undefined;
  versioned?: boolean | undefined;
}
export interface ElasticsearchDataSourceConfig {
  endpoint: string | undefined;
  awsRegion: string | undefined;
}
export interface EventBridgeDataSourceConfig {
  eventBusArn: string | undefined;
}
export interface HttpDataSourceConfig {
  endpoint?: string | undefined;
  authorizationConfig?: AuthorizationConfig | undefined;
}
export interface LambdaDataSourceConfig {
  lambdaFunctionArn: string | undefined;
}
export declare const DataSourceLevelMetricsConfig: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type DataSourceLevelMetricsConfig =
  (typeof DataSourceLevelMetricsConfig)[keyof typeof DataSourceLevelMetricsConfig];
export interface OpenSearchServiceDataSourceConfig {
  endpoint: string | undefined;
  awsRegion: string | undefined;
}
export interface RdsHttpEndpointConfig {
  awsRegion?: string | undefined;
  dbClusterIdentifier?: string | undefined;
  databaseName?: string | undefined;
  schema?: string | undefined;
  awsSecretStoreArn?: string | undefined;
}
export declare const RelationalDatabaseSourceType: {
  readonly RDS_HTTP_ENDPOINT: "RDS_HTTP_ENDPOINT";
};
export type RelationalDatabaseSourceType =
  (typeof RelationalDatabaseSourceType)[keyof typeof RelationalDatabaseSourceType];
export interface RelationalDatabaseDataSourceConfig {
  relationalDatabaseSourceType?: RelationalDatabaseSourceType | undefined;
  rdsHttpEndpointConfig?: RdsHttpEndpointConfig | undefined;
}
export declare const DataSourceType: {
  readonly AMAZON_BEDROCK_RUNTIME: "AMAZON_BEDROCK_RUNTIME";
  readonly AMAZON_DYNAMODB: "AMAZON_DYNAMODB";
  readonly AMAZON_ELASTICSEARCH: "AMAZON_ELASTICSEARCH";
  readonly AMAZON_EVENTBRIDGE: "AMAZON_EVENTBRIDGE";
  readonly AMAZON_OPENSEARCH_SERVICE: "AMAZON_OPENSEARCH_SERVICE";
  readonly AWS_LAMBDA: "AWS_LAMBDA";
  readonly HTTP: "HTTP";
  readonly NONE: "NONE";
  readonly RELATIONAL_DATABASE: "RELATIONAL_DATABASE";
};
export type DataSourceType =
  (typeof DataSourceType)[keyof typeof DataSourceType];
export interface CreateDataSourceRequest {
  apiId: string | undefined;
  name: string | undefined;
  description?: string | undefined;
  type: DataSourceType | undefined;
  serviceRoleArn?: string | undefined;
  dynamodbConfig?: DynamodbDataSourceConfig | undefined;
  lambdaConfig?: LambdaDataSourceConfig | undefined;
  elasticsearchConfig?: ElasticsearchDataSourceConfig | undefined;
  openSearchServiceConfig?: OpenSearchServiceDataSourceConfig | undefined;
  httpConfig?: HttpDataSourceConfig | undefined;
  relationalDatabaseConfig?: RelationalDatabaseDataSourceConfig | undefined;
  eventBridgeConfig?: EventBridgeDataSourceConfig | undefined;
  metricsConfig?: DataSourceLevelMetricsConfig | undefined;
}
export interface DataSource {
  dataSourceArn?: string | undefined;
  name?: string | undefined;
  description?: string | undefined;
  type?: DataSourceType | undefined;
  serviceRoleArn?: string | undefined;
  dynamodbConfig?: DynamodbDataSourceConfig | undefined;
  lambdaConfig?: LambdaDataSourceConfig | undefined;
  elasticsearchConfig?: ElasticsearchDataSourceConfig | undefined;
  openSearchServiceConfig?: OpenSearchServiceDataSourceConfig | undefined;
  httpConfig?: HttpDataSourceConfig | undefined;
  relationalDatabaseConfig?: RelationalDatabaseDataSourceConfig | undefined;
  eventBridgeConfig?: EventBridgeDataSourceConfig | undefined;
  metricsConfig?: DataSourceLevelMetricsConfig | undefined;
}
export interface CreateDataSourceResponse {
  dataSource?: DataSource | undefined;
}
export interface CreateDomainNameRequest {
  domainName: string | undefined;
  certificateArn: string | undefined;
  description?: string | undefined;
  tags?: Record<string, string> | undefined;
}
export interface DomainNameConfig {
  domainName?: string | undefined;
  description?: string | undefined;
  certificateArn?: string | undefined;
  appsyncDomainName?: string | undefined;
  hostedZoneId?: string | undefined;
  tags?: Record<string, string> | undefined;
  domainNameArn?: string | undefined;
}
export interface CreateDomainNameResponse {
  domainNameConfig?: DomainNameConfig | undefined;
}
export declare const ConflictDetectionType: {
  readonly NONE: "NONE";
  readonly VERSION: "VERSION";
};
export type ConflictDetectionType =
  (typeof ConflictDetectionType)[keyof typeof ConflictDetectionType];
export declare const ConflictHandlerType: {
  readonly AUTOMERGE: "AUTOMERGE";
  readonly LAMBDA: "LAMBDA";
  readonly NONE: "NONE";
  readonly OPTIMISTIC_CONCURRENCY: "OPTIMISTIC_CONCURRENCY";
};
export type ConflictHandlerType =
  (typeof ConflictHandlerType)[keyof typeof ConflictHandlerType];
export interface LambdaConflictHandlerConfig {
  lambdaConflictHandlerArn?: string | undefined;
}
export interface SyncConfig {
  conflictHandler?: ConflictHandlerType | undefined;
  conflictDetection?: ConflictDetectionType | undefined;
  lambdaConflictHandlerConfig?: LambdaConflictHandlerConfig | undefined;
}
export interface CreateFunctionRequest {
  apiId: string | undefined;
  name: string | undefined;
  description?: string | undefined;
  dataSourceName: string | undefined;
  requestMappingTemplate?: string | undefined;
  responseMappingTemplate?: string | undefined;
  functionVersion?: string | undefined;
  syncConfig?: SyncConfig | undefined;
  maxBatchSize?: number | undefined;
  runtime?: AppSyncRuntime | undefined;
  code?: string | undefined;
}
export interface FunctionConfiguration {
  functionId?: string | undefined;
  functionArn?: string | undefined;
  name?: string | undefined;
  description?: string | undefined;
  dataSourceName?: string | undefined;
  requestMappingTemplate?: string | undefined;
  responseMappingTemplate?: string | undefined;
  functionVersion?: string | undefined;
  syncConfig?: SyncConfig | undefined;
  maxBatchSize?: number | undefined;
  runtime?: AppSyncRuntime | undefined;
  code?: string | undefined;
}
export interface CreateFunctionResponse {
  functionConfiguration?: FunctionConfiguration | undefined;
}
export declare const GraphQLApiType: {
  readonly GRAPHQL: "GRAPHQL";
  readonly MERGED: "MERGED";
};
export type GraphQLApiType =
  (typeof GraphQLApiType)[keyof typeof GraphQLApiType];
export declare const DataSourceLevelMetricsBehavior: {
  readonly FULL_REQUEST_DATA_SOURCE_METRICS: "FULL_REQUEST_DATA_SOURCE_METRICS";
  readonly PER_DATA_SOURCE_METRICS: "PER_DATA_SOURCE_METRICS";
};
export type DataSourceLevelMetricsBehavior =
  (typeof DataSourceLevelMetricsBehavior)[keyof typeof DataSourceLevelMetricsBehavior];
export declare const OperationLevelMetricsConfig: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type OperationLevelMetricsConfig =
  (typeof OperationLevelMetricsConfig)[keyof typeof OperationLevelMetricsConfig];
export declare const ResolverLevelMetricsBehavior: {
  readonly FULL_REQUEST_RESOLVER_METRICS: "FULL_REQUEST_RESOLVER_METRICS";
  readonly PER_RESOLVER_METRICS: "PER_RESOLVER_METRICS";
};
export type ResolverLevelMetricsBehavior =
  (typeof ResolverLevelMetricsBehavior)[keyof typeof ResolverLevelMetricsBehavior];
export interface EnhancedMetricsConfig {
  resolverLevelMetricsBehavior: ResolverLevelMetricsBehavior | undefined;
  dataSourceLevelMetricsBehavior: DataSourceLevelMetricsBehavior | undefined;
  operationLevelMetricsConfig: OperationLevelMetricsConfig | undefined;
}
export declare const GraphQLApiIntrospectionConfig: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type GraphQLApiIntrospectionConfig =
  (typeof GraphQLApiIntrospectionConfig)[keyof typeof GraphQLApiIntrospectionConfig];
export declare const FieldLogLevel: {
  readonly ALL: "ALL";
  readonly DEBUG: "DEBUG";
  readonly ERROR: "ERROR";
  readonly INFO: "INFO";
  readonly NONE: "NONE";
};
export type FieldLogLevel = (typeof FieldLogLevel)[keyof typeof FieldLogLevel];
export interface LogConfig {
  fieldLogLevel: FieldLogLevel | undefined;
  cloudWatchLogsRoleArn: string | undefined;
  excludeVerboseContent?: boolean | undefined;
}
export declare const DefaultAction: {
  readonly ALLOW: "ALLOW";
  readonly DENY: "DENY";
};
export type DefaultAction = (typeof DefaultAction)[keyof typeof DefaultAction];
export interface UserPoolConfig {
  userPoolId: string | undefined;
  awsRegion: string | undefined;
  defaultAction: DefaultAction | undefined;
  appIdClientRegex?: string | undefined;
}
export declare const GraphQLApiVisibility: {
  readonly GLOBAL: "GLOBAL";
  readonly PRIVATE: "PRIVATE";
};
export type GraphQLApiVisibility =
  (typeof GraphQLApiVisibility)[keyof typeof GraphQLApiVisibility];
export interface CreateGraphqlApiRequest {
  name: string | undefined;
  logConfig?: LogConfig | undefined;
  authenticationType: AuthenticationType | undefined;
  userPoolConfig?: UserPoolConfig | undefined;
  openIDConnectConfig?: OpenIDConnectConfig | undefined;
  tags?: Record<string, string> | undefined;
  additionalAuthenticationProviders?:
    | AdditionalAuthenticationProvider[]
    | undefined;
  xrayEnabled?: boolean | undefined;
  lambdaAuthorizerConfig?: LambdaAuthorizerConfig | undefined;
  apiType?: GraphQLApiType | undefined;
  mergedApiExecutionRoleArn?: string | undefined;
  visibility?: GraphQLApiVisibility | undefined;
  ownerContact?: string | undefined;
  introspectionConfig?: GraphQLApiIntrospectionConfig | undefined;
  queryDepthLimit?: number | undefined;
  resolverCountLimit?: number | undefined;
  enhancedMetricsConfig?: EnhancedMetricsConfig | undefined;
}
export interface GraphqlApi {
  name?: string | undefined;
  apiId?: string | undefined;
  authenticationType?: AuthenticationType | undefined;
  logConfig?: LogConfig | undefined;
  userPoolConfig?: UserPoolConfig | undefined;
  openIDConnectConfig?: OpenIDConnectConfig | undefined;
  arn?: string | undefined;
  uris?: Record<string, string> | undefined;
  tags?: Record<string, string> | undefined;
  additionalAuthenticationProviders?:
    | AdditionalAuthenticationProvider[]
    | undefined;
  xrayEnabled?: boolean | undefined;
  wafWebAclArn?: string | undefined;
  lambdaAuthorizerConfig?: LambdaAuthorizerConfig | undefined;
  dns?: Record<string, string> | undefined;
  visibility?: GraphQLApiVisibility | undefined;
  apiType?: GraphQLApiType | undefined;
  mergedApiExecutionRoleArn?: string | undefined;
  owner?: string | undefined;
  ownerContact?: string | undefined;
  introspectionConfig?: GraphQLApiIntrospectionConfig | undefined;
  queryDepthLimit?: number | undefined;
  resolverCountLimit?: number | undefined;
  enhancedMetricsConfig?: EnhancedMetricsConfig | undefined;
}
export interface CreateGraphqlApiResponse {
  graphqlApi?: GraphqlApi | undefined;
}
export interface CachingConfig {
  ttl: number | undefined;
  cachingKeys?: string[] | undefined;
}
export declare const ResolverKind: {
  readonly PIPELINE: "PIPELINE";
  readonly UNIT: "UNIT";
};
export type ResolverKind = (typeof ResolverKind)[keyof typeof ResolverKind];
export declare const ResolverLevelMetricsConfig: {
  readonly DISABLED: "DISABLED";
  readonly ENABLED: "ENABLED";
};
export type ResolverLevelMetricsConfig =
  (typeof ResolverLevelMetricsConfig)[keyof typeof ResolverLevelMetricsConfig];
export interface PipelineConfig {
  functions?: string[] | undefined;
}
export interface CreateResolverRequest {
  apiId: string | undefined;
  typeName: string | undefined;
  fieldName: string | undefined;
  dataSourceName?: string | undefined;
  requestMappingTemplate?: string | undefined;
  responseMappingTemplate?: string | undefined;
  kind?: ResolverKind | undefined;
  pipelineConfig?: PipelineConfig | undefined;
  syncConfig?: SyncConfig | undefined;
  cachingConfig?: CachingConfig | undefined;
  maxBatchSize?: number | undefined;
  runtime?: AppSyncRuntime | undefined;
  code?: string | undefined;
  metricsConfig?: ResolverLevelMetricsConfig | undefined;
}
export interface Resolver {
  typeName?: string | undefined;
  fieldName?: string | undefined;
  dataSourceName?: string | undefined;
  resolverArn?: string | undefined;
  requestMappingTemplate?: string | undefined;
  responseMappingTemplate?: string | undefined;
  kind?: ResolverKind | undefined;
  pipelineConfig?: PipelineConfig | undefined;
  syncConfig?: SyncConfig | undefined;
  cachingConfig?: CachingConfig | undefined;
  maxBatchSize?: number | undefined;
  runtime?: AppSyncRuntime | undefined;
  code?: string | undefined;
  metricsConfig?: ResolverLevelMetricsConfig | undefined;
}
export interface CreateResolverResponse {
  resolver?: Resolver | undefined;
}
export declare const TypeDefinitionFormat: {
  readonly JSON: "JSON";
  readonly SDL: "SDL";
};
export type TypeDefinitionFormat =
  (typeof TypeDefinitionFormat)[keyof typeof TypeDefinitionFormat];
export interface CreateTypeRequest {
  apiId: string | undefined;
  definition: string | undefined;
  format: TypeDefinitionFormat | undefined;
}
export interface Type {
  name?: string | undefined;
  description?: string | undefined;
  arn?: string | undefined;
  definition?: string | undefined;
  format?: TypeDefinitionFormat | undefined;
}
export interface CreateTypeResponse {
  type?: Type | undefined;
}
export interface DeleteApiRequest {
  apiId: string | undefined;
}
export interface DeleteApiResponse {}
export interface DeleteApiCacheRequest {
  apiId: string | undefined;
}
export interface DeleteApiCacheResponse {}
export interface DeleteApiKeyRequest {
  apiId: string | undefined;
  id: string | undefined;
}
export interface DeleteApiKeyResponse {}
export interface DeleteChannelNamespaceRequest {
  apiId: string | undefined;
  name: string | undefined;
}
export interface DeleteChannelNamespaceResponse {}
export interface DeleteDataSourceRequest {
  apiId: string | undefined;
  name: string | undefined;
}
export interface DeleteDataSourceResponse {}
export interface DeleteDomainNameRequest {
  domainName: string | undefined;
}
export interface DeleteDomainNameResponse {}
export interface DeleteFunctionRequest {
  apiId: string | undefined;
  functionId: string | undefined;
}
export interface DeleteFunctionResponse {}
export interface DeleteGraphqlApiRequest {
  apiId: string | undefined;
}
export interface DeleteGraphqlApiResponse {}
export interface DeleteResolverRequest {
  apiId: string | undefined;
  typeName: string | undefined;
  fieldName: string | undefined;
}
export interface DeleteResolverResponse {}
export interface DeleteTypeRequest {
  apiId: string | undefined;
  typeName: string | undefined;
}
export interface DeleteTypeResponse {}
export interface DisassociateApiRequest {
  domainName: string | undefined;
}
export interface DisassociateApiResponse {}
export interface DisassociateMergedGraphqlApiRequest {
  sourceApiIdentifier: string | undefined;
  associationId: string | undefined;
}
export interface DisassociateMergedGraphqlApiResponse {
  sourceApiAssociationStatus?: SourceApiAssociationStatus | undefined;
}
export interface DisassociateSourceGraphqlApiRequest {
  mergedApiIdentifier: string | undefined;
  associationId: string | undefined;
}
export interface DisassociateSourceGraphqlApiResponse {
  sourceApiAssociationStatus?: SourceApiAssociationStatus | undefined;
}
export interface EvaluateCodeRequest {
  runtime: AppSyncRuntime | undefined;
  code: string | undefined;
  context: string | undefined;
  function?: string | undefined;
}
export interface EvaluateCodeErrorDetail {
  message?: string | undefined;
  codeErrors?: CodeError[] | undefined;
}
export interface EvaluateCodeResponse {
  evaluationResult?: string | undefined;
  error?: EvaluateCodeErrorDetail | undefined;
  logs?: string[] | undefined;
  stash?: string | undefined;
  outErrors?: string | undefined;
}
export interface EvaluateMappingTemplateRequest {
  template: string | undefined;
  context: string | undefined;
}
export interface ErrorDetail {
  message?: string | undefined;
}
export interface EvaluateMappingTemplateResponse {
  evaluationResult?: string | undefined;
  error?: ErrorDetail | undefined;
  logs?: string[] | undefined;
  stash?: string | undefined;
  outErrors?: string | undefined;
}
export interface FlushApiCacheRequest {
  apiId: string | undefined;
}
export interface FlushApiCacheResponse {}
export interface GetApiRequest {
  apiId: string | undefined;
}
export interface GetApiResponse {
  api?: Api | undefined;
}
export interface GetApiAssociationRequest {
  domainName: string | undefined;
}
export interface GetApiAssociationResponse {
  apiAssociation?: ApiAssociation | undefined;
}
export interface GetApiCacheRequest {
  apiId: string | undefined;
}
export interface GetApiCacheResponse {
  apiCache?: ApiCache | undefined;
}
export interface GetChannelNamespaceRequest {
  apiId: string | undefined;
  name: string | undefined;
}
export interface GetChannelNamespaceResponse {
  channelNamespace?: ChannelNamespace | undefined;
}
export interface GetDataSourceRequest {
  apiId: string | undefined;
  name: string | undefined;
}
export interface GetDataSourceResponse {
  dataSource?: DataSource | undefined;
}
export interface GetDataSourceIntrospectionRequest {
  introspectionId: string | undefined;
  includeModelsSDL?: boolean | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface DataSourceIntrospectionModelIndex {
  name?: string | undefined;
  fields?: string[] | undefined;
}
export declare const DataSourceIntrospectionStatus: {
  readonly FAILED: "FAILED";
  readonly PROCESSING: "PROCESSING";
  readonly SUCCESS: "SUCCESS";
};
export type DataSourceIntrospectionStatus =
  (typeof DataSourceIntrospectionStatus)[keyof typeof DataSourceIntrospectionStatus];
export interface GetDomainNameRequest {
  domainName: string | undefined;
}
export interface GetDomainNameResponse {
  domainNameConfig?: DomainNameConfig | undefined;
}
export interface GetFunctionRequest {
  apiId: string | undefined;
  functionId: string | undefined;
}
export interface GetFunctionResponse {
  functionConfiguration?: FunctionConfiguration | undefined;
}
export interface GetGraphqlApiRequest {
  apiId: string | undefined;
}
export interface GetGraphqlApiResponse {
  graphqlApi?: GraphqlApi | undefined;
}
export interface GetGraphqlApiEnvironmentVariablesRequest {
  apiId: string | undefined;
}
export interface GetGraphqlApiEnvironmentVariablesResponse {
  environmentVariables?: Record<string, string> | undefined;
}
export declare const OutputType: {
  readonly JSON: "JSON";
  readonly SDL: "SDL";
};
export type OutputType = (typeof OutputType)[keyof typeof OutputType];
export interface GetIntrospectionSchemaRequest {
  apiId: string | undefined;
  format: OutputType | undefined;
  includeDirectives?: boolean | undefined;
}
export interface GetIntrospectionSchemaResponse {
  schema?: Uint8Array | undefined;
}
export declare class GraphQLSchemaException extends __BaseException {
  readonly name: "GraphQLSchemaException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<GraphQLSchemaException, __BaseException>
  );
}
export interface GetResolverRequest {
  apiId: string | undefined;
  typeName: string | undefined;
  fieldName: string | undefined;
}
export interface GetResolverResponse {
  resolver?: Resolver | undefined;
}
export interface GetSchemaCreationStatusRequest {
  apiId: string | undefined;
}
export declare const SchemaStatus: {
  readonly Active: "ACTIVE";
  readonly Deleting: "DELETING";
  readonly Failed: "FAILED";
  readonly NotApplicable: "NOT_APPLICABLE";
  readonly Processing: "PROCESSING";
  readonly Success: "SUCCESS";
};
export type SchemaStatus = (typeof SchemaStatus)[keyof typeof SchemaStatus];
export interface GetSchemaCreationStatusResponse {
  status?: SchemaStatus | undefined;
  details?: string | undefined;
}
export interface GetSourceApiAssociationRequest {
  mergedApiIdentifier: string | undefined;
  associationId: string | undefined;
}
export interface GetSourceApiAssociationResponse {
  sourceApiAssociation?: SourceApiAssociation | undefined;
}
export interface GetTypeRequest {
  apiId: string | undefined;
  typeName: string | undefined;
  format: TypeDefinitionFormat | undefined;
}
export interface GetTypeResponse {
  type?: Type | undefined;
}
export interface ListApiKeysRequest {
  apiId: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListApiKeysResponse {
  apiKeys?: ApiKey[] | undefined;
  nextToken?: string | undefined;
}
export interface ListApisRequest {
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListApisResponse {
  apis?: Api[] | undefined;
  nextToken?: string | undefined;
}
export interface ListChannelNamespacesRequest {
  apiId: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListChannelNamespacesResponse {
  channelNamespaces?: ChannelNamespace[] | undefined;
  nextToken?: string | undefined;
}
export interface ListDataSourcesRequest {
  apiId: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListDataSourcesResponse {
  dataSources?: DataSource[] | undefined;
  nextToken?: string | undefined;
}
export interface ListDomainNamesRequest {
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListDomainNamesResponse {
  domainNameConfigs?: DomainNameConfig[] | undefined;
  nextToken?: string | undefined;
}
export interface ListFunctionsRequest {
  apiId: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListFunctionsResponse {
  functions?: FunctionConfiguration[] | undefined;
  nextToken?: string | undefined;
}
export declare const Ownership: {
  readonly CURRENT_ACCOUNT: "CURRENT_ACCOUNT";
  readonly OTHER_ACCOUNTS: "OTHER_ACCOUNTS";
};
export type Ownership = (typeof Ownership)[keyof typeof Ownership];
export interface ListGraphqlApisRequest {
  nextToken?: string | undefined;
  maxResults?: number | undefined;
  apiType?: GraphQLApiType | undefined;
  owner?: Ownership | undefined;
}
export interface ListGraphqlApisResponse {
  graphqlApis?: GraphqlApi[] | undefined;
  nextToken?: string | undefined;
}
export interface ListResolversRequest {
  apiId: string | undefined;
  typeName: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListResolversResponse {
  resolvers?: Resolver[] | undefined;
  nextToken?: string | undefined;
}
export interface ListResolversByFunctionRequest {
  apiId: string | undefined;
  functionId: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListResolversByFunctionResponse {
  resolvers?: Resolver[] | undefined;
  nextToken?: string | undefined;
}
export interface ListSourceApiAssociationsRequest {
  apiId: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface SourceApiAssociationSummary {
  associationId?: string | undefined;
  associationArn?: string | undefined;
  sourceApiId?: string | undefined;
  sourceApiArn?: string | undefined;
  mergedApiId?: string | undefined;
  mergedApiArn?: string | undefined;
  description?: string | undefined;
}
export interface ListSourceApiAssociationsResponse {
  sourceApiAssociationSummaries?: SourceApiAssociationSummary[] | undefined;
  nextToken?: string | undefined;
}
export interface ListTagsForResourceRequest {
  resourceArn: string | undefined;
}
export interface ListTagsForResourceResponse {
  tags?: Record<string, string> | undefined;
}
export interface ListTypesRequest {
  apiId: string | undefined;
  format: TypeDefinitionFormat | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListTypesResponse {
  types?: Type[] | undefined;
  nextToken?: string | undefined;
}
export interface ListTypesByAssociationRequest {
  mergedApiIdentifier: string | undefined;
  associationId: string | undefined;
  format: TypeDefinitionFormat | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface ListTypesByAssociationResponse {
  types?: Type[] | undefined;
  nextToken?: string | undefined;
}
export interface PutGraphqlApiEnvironmentVariablesRequest {
  apiId: string | undefined;
  environmentVariables: Record<string, string> | undefined;
}
export interface PutGraphqlApiEnvironmentVariablesResponse {
  environmentVariables?: Record<string, string> | undefined;
}
export interface RdsDataApiConfig {
  resourceArn: string | undefined;
  secretArn: string | undefined;
  databaseName: string | undefined;
}
export interface StartDataSourceIntrospectionRequest {
  rdsDataApiConfig?: RdsDataApiConfig | undefined;
}
export interface StartDataSourceIntrospectionResponse {
  introspectionId?: string | undefined;
  introspectionStatus?: DataSourceIntrospectionStatus | undefined;
  introspectionStatusDetail?: string | undefined;
}
export interface StartSchemaCreationRequest {
  apiId: string | undefined;
  definition: Uint8Array | undefined;
}
export interface StartSchemaCreationResponse {
  status?: SchemaStatus | undefined;
}
export interface StartSchemaMergeRequest {
  associationId: string | undefined;
  mergedApiIdentifier: string | undefined;
}
export interface StartSchemaMergeResponse {
  sourceApiAssociationStatus?: SourceApiAssociationStatus | undefined;
}
export interface TagResourceRequest {
  resourceArn: string | undefined;
  tags: Record<string, string> | undefined;
}
export interface TagResourceResponse {}
export interface UntagResourceRequest {
  resourceArn: string | undefined;
  tagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateApiRequest {
  apiId: string | undefined;
  name: string | undefined;
  ownerContact?: string | undefined;
  eventConfig?: EventConfig | undefined;
}
export interface UpdateApiResponse {
  api?: Api | undefined;
}
export interface UpdateApiCacheRequest {
  apiId: string | undefined;
  ttl: number | undefined;
  apiCachingBehavior: ApiCachingBehavior | undefined;
  type: ApiCacheType | undefined;
  healthMetricsConfig?: CacheHealthMetricsConfig | undefined;
}
export interface UpdateApiCacheResponse {
  apiCache?: ApiCache | undefined;
}
export interface UpdateApiKeyRequest {
  apiId: string | undefined;
  id: string | undefined;
  description?: string | undefined;
  expires?: number | undefined;
}
export interface UpdateApiKeyResponse {
  apiKey?: ApiKey | undefined;
}
export interface UpdateChannelNamespaceRequest {
  apiId: string | undefined;
  name: string | undefined;
  subscribeAuthModes?: AuthMode[] | undefined;
  publishAuthModes?: AuthMode[] | undefined;
  codeHandlers?: string | undefined;
  handlerConfigs?: HandlerConfigs | undefined;
}
export interface UpdateChannelNamespaceResponse {
  channelNamespace?: ChannelNamespace | undefined;
}
export interface UpdateDataSourceRequest {
  apiId: string | undefined;
  name: string | undefined;
  description?: string | undefined;
  type: DataSourceType | undefined;
  serviceRoleArn?: string | undefined;
  dynamodbConfig?: DynamodbDataSourceConfig | undefined;
  lambdaConfig?: LambdaDataSourceConfig | undefined;
  elasticsearchConfig?: ElasticsearchDataSourceConfig | undefined;
  openSearchServiceConfig?: OpenSearchServiceDataSourceConfig | undefined;
  httpConfig?: HttpDataSourceConfig | undefined;
  relationalDatabaseConfig?: RelationalDatabaseDataSourceConfig | undefined;
  eventBridgeConfig?: EventBridgeDataSourceConfig | undefined;
  metricsConfig?: DataSourceLevelMetricsConfig | undefined;
}
export interface UpdateDataSourceResponse {
  dataSource?: DataSource | undefined;
}
export interface UpdateDomainNameRequest {
  domainName: string | undefined;
  description?: string | undefined;
}
export interface UpdateDomainNameResponse {
  domainNameConfig?: DomainNameConfig | undefined;
}
export interface UpdateFunctionRequest {
  apiId: string | undefined;
  name: string | undefined;
  description?: string | undefined;
  functionId: string | undefined;
  dataSourceName: string | undefined;
  requestMappingTemplate?: string | undefined;
  responseMappingTemplate?: string | undefined;
  functionVersion?: string | undefined;
  syncConfig?: SyncConfig | undefined;
  maxBatchSize?: number | undefined;
  runtime?: AppSyncRuntime | undefined;
  code?: string | undefined;
}
export interface UpdateFunctionResponse {
  functionConfiguration?: FunctionConfiguration | undefined;
}
export interface UpdateGraphqlApiRequest {
  apiId: string | undefined;
  name: string | undefined;
  logConfig?: LogConfig | undefined;
  authenticationType: AuthenticationType | undefined;
  userPoolConfig?: UserPoolConfig | undefined;
  openIDConnectConfig?: OpenIDConnectConfig | undefined;
  additionalAuthenticationProviders?:
    | AdditionalAuthenticationProvider[]
    | undefined;
  xrayEnabled?: boolean | undefined;
  lambdaAuthorizerConfig?: LambdaAuthorizerConfig | undefined;
  mergedApiExecutionRoleArn?: string | undefined;
  ownerContact?: string | undefined;
  introspectionConfig?: GraphQLApiIntrospectionConfig | undefined;
  queryDepthLimit?: number | undefined;
  resolverCountLimit?: number | undefined;
  enhancedMetricsConfig?: EnhancedMetricsConfig | undefined;
}
export interface UpdateGraphqlApiResponse {
  graphqlApi?: GraphqlApi | undefined;
}
export interface UpdateResolverRequest {
  apiId: string | undefined;
  typeName: string | undefined;
  fieldName: string | undefined;
  dataSourceName?: string | undefined;
  requestMappingTemplate?: string | undefined;
  responseMappingTemplate?: string | undefined;
  kind?: ResolverKind | undefined;
  pipelineConfig?: PipelineConfig | undefined;
  syncConfig?: SyncConfig | undefined;
  cachingConfig?: CachingConfig | undefined;
  maxBatchSize?: number | undefined;
  runtime?: AppSyncRuntime | undefined;
  code?: string | undefined;
  metricsConfig?: ResolverLevelMetricsConfig | undefined;
}
export interface UpdateResolverResponse {
  resolver?: Resolver | undefined;
}
export interface UpdateSourceApiAssociationRequest {
  associationId: string | undefined;
  mergedApiIdentifier: string | undefined;
  description?: string | undefined;
  sourceApiAssociationConfig?: SourceApiAssociationConfig | undefined;
}
export interface UpdateSourceApiAssociationResponse {
  sourceApiAssociation?: SourceApiAssociation | undefined;
}
export interface UpdateTypeRequest {
  apiId: string | undefined;
  typeName: string | undefined;
  definition?: string | undefined;
  format: TypeDefinitionFormat | undefined;
}
export interface UpdateTypeResponse {
  type?: Type | undefined;
}
export interface DataSourceIntrospectionModelFieldType {
  kind?: string | undefined;
  name?: string | undefined;
  type?: DataSourceIntrospectionModelFieldType | undefined;
  values?: string[] | undefined;
}
export interface DataSourceIntrospectionModelField {
  name?: string | undefined;
  type?: DataSourceIntrospectionModelFieldType | undefined;
  length?: number | undefined;
}
export interface DataSourceIntrospectionModel {
  name?: string | undefined;
  fields?: DataSourceIntrospectionModelField[] | undefined;
  primaryKey?: DataSourceIntrospectionModelIndex | undefined;
  indexes?: DataSourceIntrospectionModelIndex[] | undefined;
  sdl?: string | undefined;
}
export interface DataSourceIntrospectionResult {
  models?: DataSourceIntrospectionModel[] | undefined;
  nextToken?: string | undefined;
}
export interface GetDataSourceIntrospectionResponse {
  introspectionId?: string | undefined;
  introspectionStatus?: DataSourceIntrospectionStatus | undefined;
  introspectionStatusDetail?: string | undefined;
  introspectionResult?: DataSourceIntrospectionResult | undefined;
}
